pub struct HtCodeBlockPayloadRanges {
pub cleanup: J2kCodestreamRange,
pub refinement: Option<J2kCodestreamRange>,
}Expand description
One retained cleanup/refinement record for an HTJ2K code block.
The first record for a code block contains its cleanup range and may contain the first refinement fragment. When refinement bytes are split across packets, immediately following continuation records have an empty cleanup range and a non-empty refinement range. Consumers use the code block’s declared refinement length to determine where the next block starts.
Fields
cleanup: J2kCodestreamRangeCleanup-pass payload range.
refinement: Option<J2kCodestreamRange>SigProp/MagRef payload fragment, when refinement is present.