pub struct J2kCodeBlockSegment {
pub data_offset: u32,
pub data_length: u32,
pub start_coding_pass: u8,
pub end_coding_pass: u8,
pub use_arithmetic: bool,
}Expand description
Adapter classic J2K coded segment for backend experimentation.
Fields
data_offset: u32Byte offset of this segment within the combined payload.
data_length: u32Segment payload length in bytes.
start_coding_pass: u8First coding pass covered by this segment.
end_coding_pass: u8One-past-last coding pass covered by this segment.
use_arithmetic: boolWhether this segment is decoded through the arithmetic path.